#!/bin/bash
#
# This script generates header file with internal structures from Globus sources
#
# Author: Andrey Kiryanov <kiryanov@cern.ch>
#
################################################################################

SRPMS="globus-gridftp-server globus-gridftp-server-control"
OFILE="globus_gfs_internal_hack.h"
SFILE="globus-rpm-version"
STRUCT=("globus_i_gfs_acl.h globus_i_gfs_acl_type_t  globus_gfs_acl_cb_t globus_i_gfs_acl_handle_t"
	"globus_i_gfs_data.h globus_gfs_data_reply_t globus_gfs_data_event_reply_t globus_i_gfs_data_callback_t globus_i_gfs_data_event_callback_t"
	"globus_i_gfs_data.c globus_l_gfs_data_state_t globus_l_gfs_data_handle_state_t globus_l_gfs_data_info_type_t globus_l_gfs_data_path_list_t globus_l_gfs_storattr_t globus_l_gfs_data_session_t globus_l_gfs_data_handle_t globus_l_gfs_data_operation_t"
	"globus_i_gridftp_server_control.h globus_l_gsc_data_obj_state_t globus_i_gsc_auth_cb_t globus_i_gsc_resource_cb_t globus_i_gsc_passive_cb_t globus_i_gsc_port_cb_t globus_i_gsc_transfer_cb_t globus_i_gsc_data_t globus_i_gsc_op_type_t globus_i_gsc_event_data_t globus_i_gsc_op_t"
	"globus_i_gridftp_server.h globus_i_gfs_server_close_cb_t"
	"globus_i_gfs_control.c globus_l_gfs_server_instance_t globus_l_gfs_request_info_t")

[ -n "$1" ] && OFILE="$1/$OFILE"
[ -n "$2" ] && SFILE="$2/$SFILE"
TDIR=`mktemp -d` || exit
pushd $TDIR || exit
yumdownloader --source $SRPMS || exit
for r in *.src.rpm; do
rpm2cpio $r|cpio -iu --no-absolute-filenames
done
for r in *.tar.gz; do
tar -xzf $r --strip-components 1
done
popd

cat - >$OFILE <<EOF
/*
	Automatically generated! Do not edit!

	This file contains definitions of internal Globus GridFTP structures.
	It is only needed because Globus does not provide enough information to
	callbacks in delayed passive mode, in particular it's impossible to tell
	whether we are reading or writing a file provided in data_info->pathname
*/

#include "globus_ftp_control.h"

EOF

for i in ${!STRUCT[*]}; do
LIST=(${STRUCT[$i]})
echo -e "/* From ${LIST[0]} */\n" >>$OFILE
for k in ${!LIST[*]}; do
[ $k -eq 0 ] && continue
awk "/^ *typedef / {CTX = \"\"} {CTX = CTX == \"\" ? \$0 : CTX \"\n\" \$0} /\*${LIST[$k]}/ {FC = 1} /${LIST[$k]};/ {print CTX \"\n\"} /);/ {if(FC) print CTX \"\n\"; FC = 0}" $TDIR/${LIST[0]} >>$OFILE
done
done
VER=`grep "^Version:" $TDIR/globus-gridftp-server.spec | awk "{print \\$2}"`
echo "Detected globus-gridftp-server-progs version is $VER"
echo "$VER" >$SFILE
rm -rf $TDIR
